# pryme

## written by J. Alex Ruble (Calamitizer)

([GitHub repository](https://github.com/Calamitizer/pryme))

## Overview

This is (/ will be) a Python module for various prime-related and number-theoretic operations. Each of the major functions is memoized (to file storage) for efficiency. For example, output data for `decompose(n)` (which computes the prime factorization of its argument) is stored in `./memoizations/decompose.pryme`.

## Usage Guide

`NotImplemented`

## Changelog

### v0.1 (13 March '16)

This is the first pushed version of pryme. Noteworthy features: the `Decomposition` class and various utility decorators.

## Jolly Cooperation

All contributions to and optimizations of this project are welcome. Just fork pryme on GitHub and follow your heart.

## Implementation

This code is written in Python 2.7.3. (So far) only Python standard library modules are used.

## Author

You can reach the author (Alex Ruble) most easily via GitHub ([Calamitizer](https://github.com/calamitizer)), email ([jaruble@ncsu.edu](mailto:jaruble@ncsu.edu)), or Twitter ([@aknifeallblade](https://twitter.com/aknifeallblade)).

## License

This software has no associated copyrights whatsoever (*i*.*e*. an [unlicense](http://unlicense.org/)). See `LICENSE.txt` for the full description.
